<?php

namespace App\Http\Controllers\admin\Auth;

use App\Http\Controllers\Controller;
use App\Models\Admin;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;

class AuthController extends Controller
{
   

    public function login_page()
    {

        return view('panel.pages.auth.login');
    }

    public function login_check(Request $request)
    {
        $rules = [
            'email' => 'required|email',
            'password' => 'required',
        ];

        $messages = [
            'email.required' => 'يرجى إدخال البريد الإلكتروني',
            'email.email' => 'يرجى إدخال بريد إلكتروني صالح',
            'password.required' => 'يرجى إدخال كلمة المرور',
        ];

        $this->validate($request, $rules);
    
        $credentials = ['email' => $request->email, 'password' => $request->password];
    
        if (Auth::guard('admin')->attempt($credentials)) {
            Session::flash('success', 'تمت تسجيل الدخول بنجاح');
    
            $request->session()->regenerate();
    
            return redirect()->route('home');
        }
    
        return back()->withInput($request->only('email'))->withErrors(['error' => 'يرجى التأكد من البريد الالكتروني و كلمة المرور']);
    }
    
    

    public function profile_page()
    {
        return view('panel.pages.auth.profile');
    }

    
    public function logout(Request $request)
    {
        Auth::logout();
        $request->session()->invalidate();
        Session::flash('success', 'تمت تسجيل الخروج بنجاح');
        return redirect()->route('admin.login');
    }

}
