<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\CouponRequet;
use App\Models\Coupon;
use App\Models\Product;
use Exception;
use Illuminate\Http\Request;

class CouponController extends Controller
{
    public function index()
    {
        $products=Product::all();
        $coupons = Coupon::all();
        return view('panel.pages.coupon.index', compact('coupons','products'));
    }

    public function create(CouponRequet $request)
    {
        

        $coupon = Coupon::create([
            'name' => $request->input('name'),
            'code_coupon' => $request->input('code_coupon'),
            'type_coupon' => $request->input('type_coupon'),
            'value_coupon' => $request->input('value_coupon'),
            'date_start' => $request->input('date_start'),
            'date_end' => $request->input('date_end'),
            'usage' => $request->input('usage'),
            'usage_of_user' => $request->input('usage_of_user'),
            'product_id' => $request->input('product_id'),
        ]);

        

        $coupon->save();

        return redirect()->route('admin.coupon.index')->with('success', 'Coupon created successfully.');
    }

    public function delete($id)
    {
        $coupon = Coupon::findOrFail($id);
        $coupon->delete();

        return redirect()->route('admin.coupon.index')->with('success', 'Coupon deleted successfully.');
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'code_coupon' => 'required',
            'type_coupon' => 'required|in:ratio,value',
            'value_coupon' => 'required',
            'date_start' => 'required|date',
            'date_end' => 'required|date',
            'usage' => 'required|integer',
            'usage_of_user' => 'required|integer',
            'product_id' => 'required|exists:products,id',
            'name' => 'required|string|max:255',
        ]);

        $coupon = Coupon::findOrFail($id);
        $coupon->name = $request->input('name');
        $coupon->code_coupon = $request->input('code_coupon');
        $coupon->type_coupon = $request->input('type_coupon');
        $coupon->value_coupon = $request->input('value_coupon');
        $coupon->date_start = $request->input('date_start');
        $coupon->date_end = $request->input('date_end');
        $coupon->usage = $request->input('usage');
        $coupon->usage_of_user = $request->input('usage_of_user');
        $coupon->product_id = $request->input('product_id');
        $coupon->name = $request->input('name');

        $coupon->save();

        return redirect()->route('admin.coupon.index')->with('success', 'Coupon updated successfully.');
    }

    public function status($id)
    {
        try {
            $coupon = Coupon::findOrFail($id);
            $coupon->is_delete = $coupon->is_delete == 0 ? 1 : 0;
            $coupon->save();

            return redirect()->back()->with('success', 'Status updated successfully.');
        } catch (Exception $e) {
            return redirect()->back()->with('error', 'Error updating status: ' . $e->getMessage());
        }
    }
}
