<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\ProductRequet;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class ProductsController extends Controller
{

 
    public function index()
    {
        $products = Product::orderBy('created_at','desc')->paginate(10);
        $categories = Category::all();
        return view('panel.pages.products.index', compact('products', 'categories'));
    }

    public function create(ProductRequet $request)
    {
      
        $data = $request->only([
            'name', 'short_desc', 'long_desc', 'product_spec', 
            'price', 'num_of_paces', 'category_id'
        ]);

        if ($request->hasFile('image')) {
            $data['image'] = fileUploader($request->image, 'products');
        }

        Product::create($data);

        return redirect()->route('admin.products.index')->with('success', 'Product created successfully.');
    }
    

    public function delete($id)
    {

        $product = Product::findOrFail($id);
        
        if ($product->image) {
            deleteFile($product->image);  
        }
    
        $product->delete();
    
         return redirect()->route('admin.products.index')->with('success', 'Product deleted successfully.');
    }

   public function update(Request $request, $id)
    {
        $product = Product::findOrFail($id);
        $product->name = $request->input('name');
        $product->short_desc = $request->input('short_desc');
        $product->product_spec = $request->input('product_spec');
        $product->long_desc = $request->input('long_desc');
        $product->num_of_paces = $request->input('num_of_paces');
        $product->category_id = $request->input('category_id');
        
        if ($request->hasFile('image')) {
            if ($product->image && Storage::exists($product->image)) {
                deleteFile($product->image);
           }
   
            $product->image = fileUploader($request->file('image'), 'products');
       }

        $product->save();
    
        return redirect()->route('admin.products.index')->with('success', 'Product updated successfully');
    }
    
    
}
  