<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class CouponRequet extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array
    {
        return [
            'name' => 'required',
            'code_coupon' => 'required',
            'type_coupon' => 'required|in:ratio,value',
            'value_coupon' => 'required',
            'date_start' => 'required',
            'date_end' => 'required',
            'usage' => 'required',
            'usage_of_user' => 'required',
            'product_id' => 'required|exists:products,id',
        ];
    }

    public function messages(): array
    {
        return [
            'name.required' => 'اسم القسيمة مطلوب.',
            'name.string' => 'اسم القسيمة يجب أن يكون نصًا.',
            'name.max' => 'اسم القسيمة لا يمكن أن يتجاوز 255 حرفًا.',
            
            'code_coupon.required' => 'رمز القسيمة مطلوب.',
            'code_coupon.string' => 'رمز القسيمة يجب أن يكون نصًا.',
            'code_coupon.max' => 'رمز القسيمة لا يمكن أن يتجاوز 100 حرفًا.',
            
            'type_coupon.required' => 'نوع القسيمة مطلوب.',
            'type_coupon.in' => 'نوع القسيمة يجب أن يكون "نسبة" أو "قيمة".',
            
            'value_coupon.required' => 'قيمة القسيمة مطلوبة.',
            'value_coupon.numeric' => 'قيمة القسيمة يجب أن تكون رقمًا.',
            
            'date_start.required' => 'تاريخ البدء مطلوب.',
            'date_start.date' => 'تاريخ البدء يجب أن يكون تاريخًا صالحًا.',
            
            'date_end.required' => 'تاريخ الانتهاء مطلوب.',
            'date_end.date' => 'تاريخ الانتهاء يجب أن يكون تاريخًا صالحًا.',
            'date_end.after_or_equal' => 'تاريخ الانتهاء يجب أن يكون بعد أو يساوي تاريخ البدء.',
            
            'usage.required' => 'حد الاستخدام مطلوب.',
            'usage.integer' => 'حد الاستخدام يجب أن يكون عددًا صحيحًا.',
            'usage.min' => 'حد الاستخدام يجب أن يكون على الأقل 1.',
            
            'usage_of_user.required' => 'حد الاستخدام لكل مستخدم مطلوب.',
            'usage_of_user.integer' => 'حد الاستخدام لكل مستخدم يجب أن يكون عددًا صحيحًا.',
            'usage_of_user.min' => 'حد الاستخدام لكل مستخدم يجب أن يكون على الأقل 1.',
            
            'product_id.required' => 'معرف المنتج مطلوب.',
            'product_id.exists' => 'معرف المنتج المحدد غير موجود.',
        ];
    }
    
}
