@extends('panel._layout.app')

@section('content')
<div class="row">
    <div class="col-12">
        <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#create_modal">
            <i class="mdi mdi-plus"></i> إضافة
        </button>
        <div class="card">
            <div class="card-body table-responsive">
                <div style="max-height: 500px; overflow-x: auto;">
                    <table id="oTable" class="table table-bordered dt-responsive table-responsive nowrap">
                        <thead>
                            <tr>
                                <th>#</th>
                                <th>الاسم</th>
                                <th>كود الخصم</th>
                                <th>نوع الخصم</th>
                                <th>قيمة الخصم</th>
                                <th>تاريخ البدايه</th>
                                <th>تاريخ النهايه</th>
                                <th>عدد مرات الاستخدام</th>
                                <th>عدد مرات الاستخدام لكل مستخدم</th>
                                <th>الحاله</th>
                                <th>الأدوات</th>
                                <th>تغير الحاله</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse ($coupons as $item)
                            <tr>
                                <td>{{ $item->id }}</td>
                                <td>{{ $item->name }}</td>
                                <td>{{ $item->code_coupon }}</td>
                                <td>{{ $item->type_coupon }}</td>
                                <td>{{ $item->value_coupon }}</td>
                                <td>{{ $item->date_start }}</td>
                                <td>{{ $item->date_end }}</td>
                                <td>{{ $item->usage }}</td>
                                <td>{{ $item->usage_of_user }}</td>
                                <td>
                                    {{ $item->is_delete ? 'غير مفعل' : 'مفعل' }}
                                </td>
                                <td>
                                    <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#edit_modal_{{ $item->id }}">تعديل</button>
                                </td>
                                <td>
                                    <form action="{{ route('admin.coupon.status', ['id' => $item->id]) }}" method="POST" onsubmit="return confirmDelete(event);">
                                        @csrf
                                        @method('POST')
                                        <button type="submit" class="btn btn-sm" style="background-color: {{ $item->is_delete ? '#28a745' : '#dc3545' }}; color: #fff;">
                                            <i class="fa {{ $item->is_delete ? 'fa-lock' : 'fa-unlock' }}"></i>
                                        </button>
                                    </form>
                                </td>
                            </tr>
                            @empty
                            <tr>
                                <td colspan="12">لا يوجد خصومات</td>
                            </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Create Coupon Modal -->
 <div class="modal fade" id="create_modal" tabindex="-1" role="dialog" aria-hidden="true">
    <div class="modal-dialog modal-top">
        <div class="modal-content">
            <div class="modal-header bg-light">
                <h4 class="modal-title">إضافة كود خصم جديد</h4>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-hidden="true"></button>
            </div>
            <div class="modal-body">
                <form action="{{ route('admin.coupon.create') }}" method="POST" enctype="multipart/form-data">
                    @csrf

                    <!-- Display Validation Errors -->
                    @if ($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                                @foreach ($errors->all() as $error)
                                    <li>{{ $error }}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif

                    <div class="mb-3">
                        <label for="name" class="form-label">الاسم</label>
                        <input type="text" class="form-control" name="name" id="name" placeholder="الاسم" value="{{ old('name') }}">
                        @error('name')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                    </div>

                    <div class="mb-3">
                        <label for="code_coupon" class="form-label">كود الخصم</label>
                        <input type="text" class="form-control" name="code_coupon" id="code_coupon" placeholder="كود الخصم" value="{{ old('code_coupon') }}">
                        @error('code_coupon')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                    </div>

                    <div class="mb-3">
                        <label for="type_coupon" class="form-label">نوع الخصم</label>
                        <select class="form-control" name="type_coupon" id="type_coupon">
                            <option value="ratio" {{ old('type_coupon') == 'ratio' ? 'selected' : '' }}>نسبة</option>
                            <option value="value" {{ old('type_coupon') == 'value' ? 'selected' : '' }}>قيمة ثابتة</option>
                        </select>
                        @error('type_coupon')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                    </div>

                    <div class="mb-3">
                        <label for="value_coupon" class="form-label">قيمة الخصم</label>
                        <input type="number" class="form-control" name="value_coupon" id="value_coupon" placeholder="قيمة الخصم" value="{{ old('value_coupon') }}">
                        @error('value_coupon')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                    </div>

                    <div class="mb-3">
                        <label for="date_start" class="form-label">تاريخ البداية</label>
                        <input type="date" class="form-control" name="date_start" id="date_start" value="{{ old('date_start') }}">
                        @error('date_start')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                    </div>

                    <div class="mb-3">
                        <label for="date_end" class="form-label">تاريخ النهاية</label>
                        <input type="date" class="form-control" name="date_end" id="date_end" value="{{ old('date_end') }}">
                        @error('date_end')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                    </div>

                    <div class="mb-3">
                        <label for="usage" class="form-label">عدد مرات الاستخدام</label>
                        <input type="number" class="form-control" name="usage" id="usage" value="{{ old('usage') }}">
                        @error('usage')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                    </div>

                    <div class="mb-3">
                        <label for="usage_of_user" class="form-label">عدد مرات الاستخدام لكل مستخدم</label>
                        <input type="number" class="form-control" name="usage_of_user" id="usage_of_user" value="{{ old('usage_of_user') }}">
                        @error('usage_of_user')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                    </div>

                    <div class="mb-3">
                        <label for="product_id" class="form-label">المنتج</label>
                        <select class="form-select" name="product_id" id="product_id">
                            @foreach($products as $product)
                                <option value="{{ $product->id }}" {{ old('product_id') == $product->id ? 'selected' : '' }}>{{ $product->name }}</option>
                            @endforeach
                        </select>
                        @error('product_id')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                    </div>

                    <button type="submit" class="btn btn-primary">إضافة</button>
                    <button type="button" class="btn btn-danger" data-bs-dismiss="modal">إلغاء</button>
                </form>
            </div>
        </div>
    </div>
</div>

<!-- Edit Coupon Modals -->
@foreach($coupons as $coupon)
    <div class="modal fade" id="edit_modal_{{ $coupon->id }}" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog modal-top">
            <div class="modal-content">
                <div class="modal-header bg-light">
                    <h4 class="modal-title">تعديل كود الخصم</h4>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-hidden="true"></button>
                </div>
                <div class="modal-body">
                    <form action="{{ route('admin.coupon.update', ['id' => $coupon->id]) }}" method="POST" enctype="multipart/form-data">
                        @csrf
                        @method('PUT')

                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="name_{{ $coupon->id }}" class="form-label">الاسم</label>
                            <input type="text" class="form-control" name="name" id="name_{{ $coupon->id }}" value="{{ $coupon->name }}" required>
                        </div>

                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="code_coupon_{{ $coupon->id }}" class="form-label">كود الخصم</label>
                            <input type="text" class="form-control" name="code_coupon" id="code_coupon_{{ $coupon->id }}" value="{{ $coupon->code_coupon }}" required>
                        </div>
                        
                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="type_coupon_{{ $coupon->id }}" class="form-label">نوع الخصم</label>
                            <select class="form-control" name="type_coupon" id="type_coupon_{{ $coupon->id }}" required>
                                <option value="ratio" {{ $coupon->type_coupon == 'ratio' ? 'selected' : '' }}>نسبة</option>
                                <option value="value" {{ $coupon->type_coupon == 'value' ? 'selected' : '' }}>قيمة ثابتة</option>
                            </select>
                        </div>

                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="value_coupon_{{ $coupon->id }}" class="form-label">قيمة الخصم</label>
                            <input type="number" class="form-control" name="value_coupon" id="value_coupon_{{ $coupon->id }}" value="{{ $coupon->value_coupon }}" required>
                        </div>

                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="date_start_{{ $coupon->id }}" class="form-label">تاريخ البداية</label>
                            <input type="date" class="form-control" name="date_start" id="date_start_{{ $coupon->id }}" value="{{ $coupon->date_start }}" required>
                        </div>

                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="date_end_{{ $coupon->id }}" class="form-label">تاريخ النهاية</label>
                            <input type="date" class="form-control" name="date_end" id="date_end_{{ $coupon->id }}" value="{{ $coupon->date_end }}" required>
                        </div>


                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="usage_{{ $coupon->id }}" class="form-label">عدد مرات الاستخدام</label>
                            <input type="number" class="form-control" name="usage" id="usage_{{ $coupon->id }}" value="{{ $coupon->usage }}" required>
                        </div>


                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="usage_of_user_{{ $coupon->id }}" class="form-label">عدد مرات الاستخدام لكل مستخدم</label>
                            <input type="number" class="form-control" name="usage_of_user" id="usage_of_user_{{ $coupon->id }}" value="{{ $coupon->usage_of_user }}" required>
                        </div>


                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="product_id_{{ $coupon->id }}" class="form-label">المنتج</label>
                            <select class="form-select" name="product_id" id="product_id_{{ $coupon->id }}" required>
                                @foreach($products as $product)
                                <option value="{{ $product->id }}" {{ $coupon->product_id == $product->id ? 'selected' : '' }}>{{ $product->name }}</option>
                                @endforeach
                            </select>
                        </div>


                        @error('title')
                        <div class="alert alert-danger">{{ $message }}</div>
                        @enderror
                        <div class="mb-3">
                            <label for="image_{{ $coupon->id }}" class="form-label">صورة</label>
                            <input type="file" class="form-control" name="image" id="image_{{ $coupon->id }}">
                        </div>
                        <button type="submit" class="btn btn-primary">تحديث</button>
                        <button type="button" class="btn btn-danger" data-bs-dismiss="modal">إلغاء</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
@endforeach
@endsection

<script>
    function confirmDelete(event) {
        event.preventDefault();

        Swal.fire({
            title: 'تأكيد الحذف',
            text: 'هل أنت متأكد من رغبتك في الحذف؟',
            icon: 'warning',
            showCancelButton: true,
            confirmButtonColor: '#3085d6',
            cancelButtonColor: '#d33',
            confirmButtonText: 'نعم',
            cancelButtonText: 'لا'
        }).then((result) => {
            if (result.isConfirmed) {
                event.target.submit(); // Submit the form if confirmed
            } else {
                Swal.fire('تم إلغاء الحذف', '', 'info');
            }
        });

        return false; // Prevent the default form submission
    }
</script>
